@@ -42,7 +42,7 @@ impl OutputFormat {
 /// Gets a [`Config`] from the given matches, but sets output_format to None
 ///
 /// This is meant to be used for testing
-pub fn test_config_from_matches<'a>(matches: &'a ArgMatches<'a>) -> TResult<Config<'a>> {
+pub fn test_config_from_matches(matches: &ArgMatches) -> TResult<Config> {
     let mut config = Config::try_from(matches)?;
     config.output_format = OutputFormat::None;
     Ok(config)
@@ -330,10 +330,10 @@ impl<'a> ConfigBuilder<'a> {
     }
 }
 
-impl<'config> TryFrom<&'config ArgMatches<'config>> for Config<'config> {
+impl<'config> TryFrom<&'config ArgMatches> for Config<'config> {
     type Error = CargoMSRVError;
 
-    fn try_from(matches: &'config ArgMatches<'config>) -> Result<Self, Self::Error> {
+    fn try_from(matches: &'config ArgMatches) -> Result<Self, Self::Error> {
         use crate::cli::id;
         use crate::fetch::default_target;
 
@@ -341,7 +341,9 @@ impl<'config> TryFrom<&'config ArgMatches<'config>> for Config<'config> {
             ModeIntent::List
         } else if matches.subcommand_matches(id::SUB_COMMAND_SHOW).is_some() {
             ModeIntent::Show
-        } else if matches.is_present(id::SUB_COMMAND_VERIFY) || matches.is_present(id::ARG_VERIFY) {
+        } else if matches.subcommand_matches(id::SUB_COMMAND_VERIFY).is_some()
+            || matches.is_present(id::ARG_VERIFY)
+        {
             ModeIntent::Verify
         } else {
             ModeIntent::Find
@@ -353,10 +355,10 @@ impl<'config> TryFrom<&'config ArgMatches<'config>> for Config<'config> {
         let mut builder = ConfigBuilder::new(action_intent, &target);
 
         // set the command which will be used to check if a project can build
-        let check_cmd = matches.values_of(id::ARG_CUSTOM_CHECK);
-        if let Some(cmd) = check_cmd {
-            builder = builder.check_command(cmd.collect());
-        }
+        builder = match matches.subcommand_matches(id::SUB_COMMAND_VERIFY) {
+            Some(verify_cmd) => set_custom_check_command(verify_cmd, builder),
+            None => set_custom_check_command(matches, builder),
+        };
 
         // set the cargo workspace path
         let crate_path = matches.value_of(id::ARG_SEEK_PATH);
@@ -479,6 +481,21 @@ fn parse_log_level(input: &str) -> tracing::Level {
     input.parse().unwrap_or(tracing::Level::INFO)
 }
 
+fn set_custom_check_command<'a>(
+    matches: &'a ArgMatches,
+    builder: ConfigBuilder<'a>,
+) -> ConfigBuilder<'a> {
+    use crate::cli::id;
+
+    let check_cmd = matches.values_of(id::ARG_CUSTOM_CHECK);
+
+    if let Some(custom_cmd) = check_cmd {
+        builder.check_command(custom_cmd.collect())
+    } else {
+        builder
+    }
+}
+
 macro_rules! as_sub_command_config {
     ($subcmd:ident, $variant:ident, $out_type:ty) => {
         pub(crate) fn $subcmd(&self) -> &$out_type {
