@@ -1,19 +1,20 @@
-use crate::config::ModeIntent;
+use std::borrow::Cow;
 
 use console::{style, Term};
 use indicatif::{ProgressBar, ProgressStyle};
 use rust_releases::semver;
-use std::borrow::Cow;
 
-pub struct HumanPrinter<'s, 't> {
+use crate::config::ModeIntent;
+
+pub struct HumanPrinter<'a> {
     term: Term,
     progress: ProgressBar,
-    toolchain: &'s str,
-    cmd: &'t str,
+    toolchain: &'a str,
+    cmd: &'a str,
 }
 
-impl std::fmt::Debug for HumanPrinter<'_, '_> {
-    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+impl std::fmt::Debug for HumanPrinter<'_> {
+    fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
         f.write_fmt(format_args!(
             "toolchain = {}, cmd = {}",
             self.toolchain, self.cmd
@@ -21,8 +22,8 @@ impl std::fmt::Debug for HumanPrinter<'_, '_> {
     }
 }
 
-impl<'s, 't> HumanPrinter<'s, 't> {
-    pub fn new(steps: u64, toolchain: &'s str, cmd: &'t str) -> Self {
+impl<'a> HumanPrinter<'a> {
+    pub fn new(steps: u64, toolchain: &'a str, cmd: &'a str) -> Self {
         let term = Term::stderr();
 
         let progress = ProgressBar::new(steps).with_style(
@@ -40,8 +41,9 @@ impl<'s, 't> HumanPrinter<'s, 't> {
 
     fn welcome(&self, target: &str, cmd: &str, action_intent: ModeIntent) {
         let verb = match action_intent {
-            ModeIntent::DetermineMSRV => "Determining",
-            ModeIntent::VerifyMSRV => "Verifying",
+            ModeIntent::Find => "Determining",
+            ModeIntent::Verify => "Verifying",
+            ModeIntent::List | ModeIntent::Show => "",
         };
 
         let _ = self.term.write_line(
@@ -74,7 +76,7 @@ impl<'s, 't> HumanPrinter<'s, 't> {
     }
 
     fn set_progress_bar_length(&self, len: u64) {
-        self.progress.set_length(len)
+        self.progress.set_length(len);
     }
 
     fn complete_step(&self, message: impl Into<Cow<'static, str>>) {
@@ -89,7 +91,7 @@ impl<'s, 't> HumanPrinter<'s, 't> {
             style("Finished").green().bold(),
             message,
             style(version).cyan()
-        ))
+        ));
     }
 
     fn finish_with_err(&self, cmd: &str) {
@@ -106,8 +108,12 @@ impl<'s, 't> HumanPrinter<'s, 't> {
     }
 }
 
-impl<'s, 't> crate::Output for HumanPrinter<'s, 't> {
+impl<'a> crate::Output for HumanPrinter<'a> {
     fn mode(&self, action: ModeIntent) {
+        if let ModeIntent::List | ModeIntent::Show = action {
+            return;
+        }
+
         self.welcome(self.toolchain, self.cmd, action);
     }
 
@@ -145,14 +151,32 @@ impl<'s, 't> crate::Output for HumanPrinter<'s, 't> {
         }
     }
 
-    fn finish_success(&self, mode: ModeIntent, version: &semver::Version) {
-        match mode {
-            ModeIntent::DetermineMSRV => self.finish_with_ok("The MSRV is:", version),
-            ModeIntent::VerifyMSRV => self.finish_with_ok("Satisfied MSRV check:", version),
+    fn finish_success(&self, mode: ModeIntent, version: Option<&semver::Version>) {
+        // for determine-msrv and verify-msrv, we report the status
+        if let Some(version) = version {
+            match mode {
+                ModeIntent::Find => self.finish_with_ok("The MSRV is:", version),
+                ModeIntent::Verify => self.finish_with_ok("Satisfied MSRV check:", version),
+                ModeIntent::Show => {
+                    let _ = self.term.write_line(&format!("{}", version));
+                }
+                ModeIntent::List => {}
+            }
         }
     }
 
-    fn finish_failure(&self, _mode: ModeIntent, cmd: &str) {
-        self.finish_with_err(cmd)
+    fn finish_failure(&self, mode: ModeIntent, cmd: Option<&str>) {
+        if let ModeIntent::Show = mode {
+            let _ = self.term.write_line("No MSRV in Cargo manifest");
+            return;
+        }
+
+        if let Some(cmd) = cmd {
+            self.finish_with_err(cmd);
+        }
+    }
+
+    fn write_line(&self, content: &str) {
+        let _ = self.progress.println(content);
     }
 }
